# Spoffy

[![CircleCI](https://circleci.com/gh/steinitzu/spoffy/tree/master.svg?style=svg)](https://circleci.com/gh/steinitzu/spoffy/tree/master)
[![Documentation Status](https://readthedocs.org/projects/spoffy/badge/?version=latest&style=flat-square)](https://spoffy.readthedocs.io/en/latest/?badge=latest)


The IDE friendly sync and async [Spotify API](https://developer.spotify.com/documentation/web-api/) wrapper for python.

Read the docs: https://spoffy.readthedocs.io


# Install

```
pip install spoffy
```
Python3.6 and newer are supported



